Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type TemperatureSensorInfo ¶
type TemperatureSensorInfo struct {
SensorName string `json:"sensor_name"`
Temperature float64 `json:"temperature"`
CriticalThreshold float64 `json:"critical_threshold"` // a temperature threshold set by sensor, driver or configuration
Unit string `json:"unit"`
}
func ReadTemperatureSensors ¶
func ReadTemperatureSensors() ([]*TemperatureSensorInfo, error)
ReadTemperatureSensors tries to read temperature sensors via sysfs interface: https://www.kernel.org/doc/Documentation/hwmon/sysfs-interface
Click to show internal directories.
Click to hide internal directories.